local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local rune = x.Rune
local target = x.Target
local variable = x.Variables

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

-- Example flash color coding:
-- White - Default
-- Yellow - Limited Time or No Global Cooldown
-- Purple - AOE or Positional Damage
-- Blue - AOE Debuff
-- Orange - Finishing Move
-- Aqua - Spell Interrupt, Reflect or Dispel
-- Green - Self Buff or Turn Autocast On
-- Red - Emergency Mitigation Cooldowns or Turn Autocast Off
-- Pink - Optional

a.spells["raise_dead"] = {
	ID = 46584--[[Raise Dead]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.ShouldPermanentBuff and not UnitExists("pet")
	end,
	FlashColor = "Green",
}

--[[
  ____            _       _         ___ _                                         _         _   _                                     _     
 |  _ \ __ _  ___(_) __ _| |___    |_ _| |_ ___ _ __ ___  ___      __ _ _ __   __| |   ___ | |_| |__   ___ _ __    ___   __ _  ___ __| |___ 
 | |_) / _` |/ __| |/ _` | / __|    | || __/ _ \ '_ ` _ \/ __|    / _` | '_ \ / _` |  / _ \| __| '_ \ / _ \ '__|  / _ \ / _` |/ __/ _` / __|
 |  _ < (_| | (__| | (_| | \__ \_   | || ||  __/ | | | | \__ \_  | (_| | | | | (_| | | (_) | |_| | | |  __/ |    | (_) | (_| | (_| (_| \__ \
 |_| \_\__,_|\___|_|\__,_|_|___( ) |___|\__\___|_| |_| |_|___( )  \__,_|_| |_|\__,_|  \___/ \__|_| |_|\___|_|     \___/ \__, |\___\__,_|___/
                               |/                            |/                                                         |___/               ]]
a.spells["arcane_torrent,if=runic_power.deficit>65&(pet.gargoyle.active|!talent.summon_gargoyle.enabled)&rune.deficit>=5"] = {
	ID = 50613--[[Arcane Torrent]],
	NoGCD = true,
	FlashColor = "Yellow",
	CheckFirst = function(z)
		return x.UseLongCD and x.RunicPowerDeficit > 65 and (cooldown.summon_gargoyle.remains > 150 or not talent.summon_gargoyle.enabled) and x.Runes <= 1
	end,
}

a.spells["blood_fury,if=pet.gargoyle.active|!talent.summon_gargoyle.enabled"] = {
	ID = 20572--[[Blood Fury]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and (cooldown.summon_gargoyle.remains > 150 or not talent.summon_gargoyle.enabled)
	end,
	FlashColor = "Yellow",
}

a.spells["berserking,if=pet.gargoyle.active|!talent.summon_gargoyle.enabled"] = {
	ID = 26297--[[Berserking]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and (cooldown.summon_gargoyle.remains > 150 or not talent.summon_gargoyle.enabled)
	end,
	FlashColor = "Yellow",
}

,"use_items"

a.spells["use_item,name=feloiled_infernal_machine,if=pet.gargoyle.active|!talent.summon_gargoyle.enabled"] = {
	Type = "item",
	ID = 144482--[[Fel-Oiled Infernal Machine]],
	NoGCD = true,
	EnemyTargetNeeded = true,
	CheckFirst =  function(z)
		return x.UseLongCD and (cooldown.summon_gargoyle.remains > 150 or not talent.summon_gargoyle.enabled)
	end,
	FlashColor = "Yellow",
}

a.spells["use_item,name=ring_of_collapsing_futures,if=(buff.temptation.stack=0&target.time_to_die>60)|target.time_to_die<60"] = {
	Type = "item",
	ID = 142173--[[Ring of Collapsing Futures]],
	NoGCD = true,
	EnemyTargetNeeded = true,
	CheckFirst =  function(z)
		return x.UseLongCD and ((buff.temptation.stack==0 and target.time_to_die > 60) or target.time_to_die < 60)
	end,
	FlashColor = "Yellow",
}

a.spells["potion,if=cooldown.army_of_the_dead.ready|pet.gargoyle.active|buff.unholy_frenzy.up"] = {
	Type = "item",
	ID = 229206--[[Potion of Prolonged Power]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	CheckFirst =  function(z)
		return s.Boss("target") and (cooldown.army_of_the_dead.ready or cooldown.summon_gargoyle.remains > 150 or buff.unholy_frenzy.up)
	end,
	FlashColor = "Yellow",
	FlashID = {229206--[[Potion of Prolonged Power]], 127844--[[Potion of the Old War]]},
}

--[[
  __  __       _       _        _        __     ___            _            _     ____  _                        
 |  \/  | __ _(_)_ __ | |_ __ _(_)_ __   \ \   / (_)_ __ _   _| | ___ _ __ | |_  |  _ \| | __ _  __ _ _   _  ___ 
 | |\/| |/ _` | | '_ \| __/ _` | | '_ \   \ \ / /| | '__| | | | |/ _ \ '_ \| __| | |_) | |/ _` |/ _` | | | |/ _ \
 | |  | | (_| | | | | | || (_| | | | | |   \ V / | | |  | |_| | |  __/ | | | |_  |  __/| | (_| | (_| | |_| |  __/
 |_|  |_|\__,_|_|_| |_|\__\__,_|_|_| |_|    \_/  |_|_|   \__,_|_|\___|_| |_|\__| |_|   |_|\__,_|\__, |\__,_|\___|
                                                                                                |___/            ]]
a.spells["outbreak,target_if=(dot.virulent_plague.tick_time_remains+tick_time<=dot.virulent_plague.remains)&dot.virulent_plague.remains<=gcd"] = {
	ID = 77575--[[Outbreak]],
	CheckFirst = function(z)
		return --[[(dot.virulent_plague.tick_time_remains+tick_time <= dot.virulent_plague.remains) and]] dot.virulent_plague.remains <= x.MaxGCD
	end,
}

--[[
                                  _                   _     _                         
   ___  _ __         __ _  ___ __| |   ___ ___   ___ | | __| | _____      ___ __  ___ 
  / _ \| '_ \ _____ / _` |/ __/ _` |  / __/ _ \ / _ \| |/ _` |/ _ \ \ /\ / / '_ \/ __|
 | (_) | | | |_____| (_| | (_| (_| | | (_| (_) | (_) | | (_| | (_) \ V  V /| | | \__ \
  \___/|_| |_|      \__, |\___\__,_|  \___\___/ \___/|_|\__,_|\___/ \_/\_/ |_| |_|___/
                    |___/                                                             ]]

a.spells["death_strike,if=buff.dark_succor.up&health.pct<0.8"] = {
	ID = 49998--[[Death Strike]],
	FlashBlink = true,
	Continue = true,
	FlashColor = "Red",
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return buff.dark_succor.up and x.HealthPercent < 80
	end,
}

a.spells["army_of_the_dead"] = {
	ID = 42650--[[Army of the Dead]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.UseLongCD
	end,
}

a.spells["apocalypse,if=debuff.festering_wound.stack>=4"] = {
	ID = 275699--[[Apocalypse]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.UseLongCD and debuff.festering_wound.stack >= 4
	end,
}

a.spells["dark_transformation"] = {
	ID = 63560--[[Dark Transformation]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return UnitExists("pet") and x.PetActiveEnemy
	end,
}

a.spells["summon_gargoyle,if=runic_power.deficit<14"] = {
	ID = 49206--[[Summon Gargoyle]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit < 14
	end,
}

a.spells["unholy_frenzy,if=debuff.festering_wound.stack<4"] = {
	ID = 207289--[[Unholy Frenzy]],
	CheckFirst = function(z)
		return x.UseLongCD and debuff.festering_wound.stack < 4
	end,
}

a.spells["unholy_frenzy,if=active_enemies>=2&((cooldown.death_and_decay.remains<=gcd&!talent.defile.enabled)|(cooldown.defile.remains<=gcd&talent.defile.enabled))"] = {
	ID = 207289--[[Unholy Frenzy]],
	CheckFirst = function(z)
		return x.UseLongCD and (x.ActiveEnemies >= 2 and ((cooldown.death_and_decay.remains <= x.MaxGCD and not talent.defile.enabled) or (cooldown.defile.remains <= x.MaxGCD and talent.defile.enabled)))
	end,
}

a.spells["soul_reaper,target_if=(target.time_to_die<8|rune<=2)&!buff.unholy_frenzy.up"] = {
	ID = 130736--[[Soul Reaper]],
	CheckFirst = function(z)
		return (target.time_to_die < 8 or x.Runes <= 2) and not buff.unholy_frenzy.up
	end,
}

a.spells["unholy_blight"] = {
	ID = 115989--[[Unholy Blight]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return x.InCombat
	end,
}

--[[
  ____          _ _       _       _             _         _____ 
 / ___|_      _(_) |_ ___| |__   | |_ ___      / \   ___ | ____|
 \___ \ \ /\ / / | __/ __| '_ \  | __/ _ \    / _ \ / _ \|  _|  
  ___) \ V  V /| | || (__| | | | | || (_) |  / ___ \ (_) | |___ 
 |____/ \_/\_/ |_|\__\___|_| |_|  \__\___/  /_/   \_\___/|_____|
                                                                ]]

a.spells["death_and_decay,if=cooldown.apocalypse.remains"] = {
	ID = 43265--[[Death and Decay]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.InCombat and (cooldown.apocalypse.remains > 0 or not x.UseLongCD)
	end,
}

a.spells["defile"] = {
	ID = 152280--[[Defile]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return talent.defile.enabled
	end,
}

a.spells["epidemic,if=death_and_decay.ticking&rune<2&!variable.pooling_for_gargoyle"] = {
	ID = 207317--[[Epidemic]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return buff.death_and_decay.up and x.Runes < 2 and not variable.pooling_for_gargoyle
	end,
}

a.spells["death_coil,if=death_and_decay.ticking&rune<2&!variable.pooling_for_gargoyle"] = {
	ID = 47541--[[Death Coil]],
	CheckFirst = function(z)
		return buff.death_and_decay.up and x.Runes < 2 and not variable.pooling_for_gargoyle
	end,
}

a.spells["scourge_strike,if=death_and_decay.ticking&cooldown.apocalypse.remains"] = {
	ID = 55090--[[Scourge Strike]],
	CheckFirst = function(z)
		return buff.death_and_decay.up and (cooldown.apocalypse.remains > 0 or not x.UseLongCD)
	end,
}

a.spells["clawing_shadows,if=death_and_decay.ticking&cooldown.apocalypse.remains"] = {
	ID = 207311--[[Clawing Shadows]],
	CheckFirst = function(z)
		return buff.death_and_decay.up and (cooldown.apocalypse.remains > 0 or not x.UseLongCD)
	end,
}

a.spells["epidemic,if=!variable.pooling_for_gargoyle"] = {
	ID = 207317--[[Epidemic]],
	NoRangeCheck = true,
	CheckFirst = function(z)
		return not variable.pooling_for_gargoyle
	end,
}

a.spells["festering_strike,target_if=debuff.festering_wound.stack<=1&cooldown.death_and_decay.remains"] = {
	ID = 85948--[[Festering Strike]],
	CheckFirst = function(z)
		return debuff.festering_wound.stack <= 1 and cooldown.death_and_decay.remains > 0
	end,
}

a.spells["festering_strike,if=talent.bursting_sores.enabled&spell_targets.bursting_sores>=2&debuff.festering_wound.stack<=1"] = {
	ID = 85948--[[Festering Strike]],
	CheckFirst = function(z)
		return talent.bursting_sores.enabled and x.ActiveEnemies >= 2 and debuff.festering_wound.stack <= 1
	end,
}

a.spells["death_coil,if=buff.sudden_doom.react&rune.deficit>=4"] = {
	ID = 47541--[[Death Coil]],
	CheckFirst = function(z)
		return buff.sudden_doom.up and x.Runes <= 2
	end,
}

--[[
  ____        __             _ _     ____       _        _   _             
 |  _ \  ___ / _| __ _ _   _| | |_  |  _ \ ___ | |_ __ _| |_(_) ___  _ __  
 | | | |/ _ \ |_ / _` | | | | | __| | |_) / _ \| __/ _` | __| |/ _ \| '_ \ 
 | |_| |  __/  _| (_| | |_| | | |_  |  _ < (_) | || (_| | |_| | (_) | | | |
 |____/ \___|_|  \__,_|\__,_|_|\__| |_| \_\___/ \__\__,_|\__|_|\___/|_| |_|
                                                                           ]]
a.spells["death_coil,if=buff.sudden_doom.react&!variable.pooling_for_gargoyle|pet.gargoyle.active"] = {
	ID = 47541--[[Death Coil]],
	CheckFirst = function(z)
		return buff.sudden_doom.up and not variable.pooling_for_gargoyle or cooldown.summon_gargoyle.remains > 150
	end,
}

a.spells["death_coil,if=runic_power.deficit<14&(cooldown.apocalypse.remains>5|debuff.festering_wound.stack>4)&!variable.pooling_for_gargoyle"] = {
	ID = 47541--[[Death Coil]],
	CheckFirst = function(z)
		return x.RunicPowerDeficit < 14 and ((cooldown.apocalypse.remains > 5 or not x.UseLongCD ) or debuff.festering_wound.stack > 4) and not variable.pooling_for_gargoyle
	end,
}

a.spells["death_and_decay,if=talent.pestilence.enabled&cooldown.apocalypse.remains"] = {
	ID = 43265--[[Death and Decay]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.InCombat and talent.pestilence.enabled and (cooldown.apocalypse.remains > 0 or not x.UseLongCD)
	end,
}

a.spells["defile,if=cooldown.apocalypse.remains"] = {
	ID = 152280--[[Defile]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return talent.defile.enabled and (cooldown.apocalypse.remains > 0 or not x.UseLongCD)
	end,
}

a.spells["scourge_strike,if=((debuff.festering_wound.up&cooldown.apocalypse.remains>5)|debuff.festering_wound.stack>4)&cooldown.army_of_the_dead.remains>5"] = {
	ID = 55090--[[Scourge Strike]],
	CheckFirst = function(z)
		return ((debuff.festering_wound.up and (cooldown.apocalypse.remains > 5 or not x.UseLongCD)) or debuff.festering_wound.stack > 4) and (cooldown.army_of_the_dead.remains > 5 or not x.UseLongCD)
	end,
}

a.spells["clawing_shadows,if=((debuff.festering_wound.up&cooldown.apocalypse.remains>5)|debuff.festering_wound.stack>4)&cooldown.army_of_the_dead.remains>5"] = {
	ID = 207311--[[Clawing Shadows]],
	CheckFirst = function(z)
		return ((debuff.festering_wound.up and (cooldown.apocalypse.remains > 5 or not x.UseLongCD)) or debuff.festering_wound.stack > 4) and (cooldown.army_of_the_dead.remains > 5 or not x.UseLongCD)
	end,
}

a.spells["death_coil,if=runic_power.deficit<20&!variable.pooling_for_gargoyle"] = {
	ID = 47541--[[Death Coil]],
	CheckFirst = function(z)
		return x.RunicPowerDeficit < 20 and not variable.pooling_for_gargoyle
	end,
}

a.spells["festering_strike,if=((((debuff.festering_wound.stack<4&!buff.unholy_frenzy.up)|debuff.festering_wound.stack<3)&cooldown.apocalypse.remains<3)|debuff.festering_wound.stack<1)&cooldown.army_of_the_dead.remains>5"] = {
	ID = 85948--[[Festering Strike]],
	CheckFirst = function(z)
		return ((((debuff.festering_wound.stack < 4 and not buff.unholy_frenzy.up) or debuff.festering_wound.stack < 3) and cooldown.apocalypse.remains < 3) or debuff.festering_wound.stack < 1) and (cooldown.army_of_the_dead.remains > 5 or not x.UseLongCD)
	end,
}

a.spells["death_coil,if=!variable.pooling_for_gargoyle"] = {
	ID = 47541--[[Death Coil]],
	CheckFirst = function(z)
		return not variable.pooling_for_gargoyle
	end,
}
